import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 600;
const height = 400;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 10;
const eyeOffsetX = 80;
const eyeOffsetY = 60;
const eyeRadius = 30;
const mouthWidth = 20;
const mouthRadius = 100;
const earWidth = 60;
const earHeight = 80;
const noseWidth = 30; // Increased size of the nose
const noseHeight = 30; // Increased size of the nose
const cigaretteWidth = 10; // Increased size of the cigarette
const cigaretteLength = 40; // Increased size of the cigarette
const cigaretteXOffset = 5; // Adjusted position of the cigarette horizontally
const cigaretteYOffset = 10; // Adjusted position of the cigarette vertically

const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      {/* Face */}
      <circle
        r={centerY - strokeWidth / 2}
        fill="yellow"
        stroke="black"
        strokeWidth={strokeWidth}
      />
      {/* Ears */}
      <ellipse
        cx={-centerX * 0.8} // Adjusted position of the left ear
        cy={-centerY * 0.8} // Adjusted position of the left ear
        rx={earWidth}
        ry={earHeight}
        fill="yellow"
        stroke="black"
        strokeWidth={2}
      />
      <ellipse
        cx={centerX * 0.8} // Adjusted position of the right ear
        cy={-centerY * 0.8} // Adjusted position of the right ear
        rx={earWidth}
        ry={earHeight}
        fill="yellow"
        stroke="black"
        strokeWidth={2}
      />
      {/* Eyes */}
      <circle
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        strokeWidth={2}
      />
      <circle
        cx={eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        strokeWidth={2}
      />
      {/* Mouth */}
      <path
        d={mouthArc()}
        fill="none"
        stroke="black"
        strokeWidth={2}
      />
      {/* Nose */}
      <ellipse
        cx={0}
        cy={-eyeOffsetY / 2}
        rx={noseWidth}
        ry={noseHeight}
        fill="red"
      />
      {/* Cigarette */}
      <line
        x1={-noseWidth / 2 - cigaretteXOffset} // Adjusted position of the cigarette
        y1={-eyeOffsetY / 2 + cigaretteYOffset} // Adjusted position of the cigarette
        x2={
          -noseWidth / 2 -
          cigaretteXOffset -
          cigaretteLength
        } // Adjusted position of the cigarette
        y2={-eyeOffsetY / 2 + cigaretteYOffset} // Adjusted position of the cigarette
        stroke="black"
        strokeWidth={cigaretteWidth} // Increased size of the cigarette
      />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
